@@ -488,7 +488,7 @@ SQLRETURN MADB_DbcFree(MADB_Dbc *Connection)
 SQLRETURN MADB_Dbc_GetCurrentDB(MADB_Dbc *Connection, SQLPOINTER CurrentDB, SQLINTEGER CurrentDBLength, 
                                 SQLSMALLINT *StringLengthPtr, my_bool isWChar) 
 {
-  SQLHANDLE Stmt;
+  MADB_Stmt *Stmt;
   SQLRETURN ret;
   SQLLEN Size;
   char Buffer[65 * sizeof(WCHAR)];
@@ -497,14 +497,14 @@ SQLRETURN MADB_Dbc_GetCurrentDB(MADB_Dbc *Connection, SQLPOINTER CurrentDB, SQLI
   ret= MA_SQLAllocHandle(SQL_HANDLE_STMT, (SQLHANDLE) Connection, &Stmt);
   if (!SQL_SUCCEEDED(ret))
     return ret;
-  if (!SQL_SUCCEEDED(MA_SQLExecDirect(Stmt, (SQLCHAR *)"SELECT IF(DATABASE() IS NOT NULL,DATABASE(),'null')", SQL_NTS)) ||
-      !SQL_SUCCEEDED(MA_SQLFetch(Stmt)))
+  if (!SQL_SUCCEEDED(Stmt->Methods->ExecDirect(Stmt, (SQLCHAR *)"SELECT IF(DATABASE() IS NOT NULL,DATABASE(),'null')", SQL_NTS)) ||
+    !SQL_SUCCEEDED(Stmt->Methods->Fetch(Stmt)))
   {
     MADB_CopyError(&Connection->Error, &((MADB_Stmt *)Stmt)->Error);
     goto end;
   }
   
-  ret= ((MADB_Stmt*)Stmt)->Methods->GetData(Stmt, 1, SQL_CHAR, Buffer, 65, &Size, TRUE);
+  ret= Stmt->Methods->GetData(Stmt, 1, SQL_CHAR, Buffer, 65, &Size, TRUE);
  /* Size= (SQLINTEGER)MADB_SetString(isWChar ? Connection->CodePage : 0, CurrentDB, 
                       (isWChar) ? (int)(MIN(Size + sizeof(SQLWCHAR), CurrentDBLength) / sizeof(SQLWCHAR)) : 
                       (int)(MIN(Size + 1, CurrentDBLength)),
@@ -1057,14 +1057,13 @@ SQLRETURN MADB_DbcGetInfo(MADB_Dbc *Dbc, SQLUSMALLINT InfoType, SQLPOINTER InfoV
     break;
   case SQL_DBMS_VER:
     {
-      char Version[11];
+      char Version[13];
       ulong ServerVersion= 0L;
-      unsigned int Major=0, Minor=0, Patch= 0;
       
       if (Dbc->mariadb)
       {
         ServerVersion= mysql_get_server_version(Dbc->mariadb);
-        my_snprintf(Version, 11, "%02u.%02u.%06u", ServerVersion / 10000,
+        _snprintf(Version, sizeof(Version), "%02u.%02u.%06u", ServerVersion / 10000,
                     (ServerVersion % 10000) / 100, ServerVersion % 100);
       }
       else
