@@ -32,6 +32,7 @@ void CloseMultiStatements(MADB_Stmt *Stmt)
   }
   MADB_FREE(Stmt->MultiStmts);
   Stmt->MultiStmtCount= 0;
+  Stmt->stmt= NULL;
 }
 
 
@@ -84,16 +85,24 @@ unsigned int GetMultiStatements(MADB_Stmt *Stmt, char *StmtStr, SQLINTEGER Lengt
   {
     end= StmtStr + Length - 1;
     while (end > StmtStr && (isspace(*end) || *end == ';'))
+    {
       --end;
-    Length= (SQLINTEGER)(end - StmtStr);
+      --Length;
+    }
   }
-  p= StmtCopy= my_strdup(StmtStr, MYF(0));
+  /* We can have here not NULL-terminated string as a source, thus we need to allocate, copy meaningful characters and
+     add NULL */
+  p= StmtCopy= MADB_ALLOC(Length + 1);
+  strncpy(StmtCopy, StmtStr, Length);
+  StmtCopy[Length]= '\0';
+
+  end= StmtCopy + Length;
   
-  while (p < StmtCopy + Length)
+  while (p < end)
   {
     if (wait_char)
     {
-      if (*p == wait_char && *prev != '\\') /* What if that is escaped backslash? */
+      if (*p == wait_char && *prev != '\\')
       {
         wait_char= 0;
       }
@@ -102,7 +111,7 @@ unsigned int GetMultiStatements(MADB_Stmt *Stmt, char *StmtStr, SQLINTEGER Lengt
     {
       switch (*p) {
       case '-':
-        if (!STRING_OR_COMMENT() && (p < StmtCopy + Length + 1) && (char)*(p+1) ==  '-')
+        if (!STRING_OR_COMMENT() && (p < end - 1) && (char)*(p+1) ==  '-')
         {
           wait_char= '\n';
         }
@@ -121,19 +130,26 @@ unsigned int GetMultiStatements(MADB_Stmt *Stmt, char *StmtStr, SQLINTEGER Lengt
         }
         break;
       case '/':
-        if (!STRING_OR_COMMENT() && (p < StmtCopy + Length + 1) && (char)*(p+1) ==  '*')
+        if (!STRING_OR_COMMENT() && (p < end - 1) && (char)*(p+1) ==  '*')
           comment= 1;
         else if (comment && (p > StmtCopy) && (char)*(prev) == '*')
           comment= 0;
         break;
       case '"':
-        if (prev && *prev != '\\')
-          quote[0] = !STRING_OR_COMMENT();
+        quote[0] = !STRING_OR_COMMENT();
         break;
       case '\'':
-        if (prev && *prev != '\\')
-          quote[1] = !STRING_OR_COMMENT();
+        quote[1] = !STRING_OR_COMMENT();
         break;
+      case '\\':
+        /* *end is \0, so we are safe here to increment by 2 bytes */
+        if ((Stmt->Connection->mariadb->server_status & SERVER_STATUS_NO_BACKSLASH_ESCAPES) == 0  && p < end - 1)
+        {
+          /* Skipping escaped character and resetting prev */
+          p+= 2;
+          prev= 0;
+          continue;
+        }
       default:
         break;
       }
@@ -157,7 +173,7 @@ unsigned int GetMultiStatements(MADB_Stmt *Stmt, char *StmtStr, SQLINTEGER Lengt
     {
       /* Need to be incremented before CloseMultiStatements() */
       ++Stmt->MultiStmtCount;
-      Stmt->MultiStmts[i]= mysql_stmt_init(Stmt->Connection->mariadb);
+      Stmt->MultiStmts[i]= i == 0 ? Stmt->stmt : mysql_stmt_init(Stmt->Connection->mariadb);
       MDBUG_C_PRINT(Stmt->Connection, "-->inited&preparing %0x(%d)", Stmt->MultiStmts[i], i);
       if (mysql_stmt_prepare(Stmt->MultiStmts[i], p, (unsigned long)strlen(p)))
       {
@@ -229,7 +245,7 @@ int MADB_KeyTypeCount(MADB_Dbc *Connection, char *TableName, int KeyFlag)
   if (MA_SQLAllocHandle(SQL_HANDLE_STMT, (SQLHANDLE)Connection, (SQLHANDLE*)&Stmt) == SQL_ERROR ||
       Stmt->Methods->Prepare(Stmt, (SQLCHAR *)StmtStr, SQL_NTS) == SQL_ERROR ||
       Stmt->Methods->Execute(Stmt) == SQL_ERROR ||
-      Stmt->Methods->Fetch(Stmt, FALSE) == SQL_ERROR)
+      Stmt->Methods->Fetch(Stmt) == SQL_ERROR)
       goto end;
   KeyStmt= (MADB_Stmt *)Stmt;
   for (i=0; i < mysql_stmt_field_count(KeyStmt->stmt); i++)
@@ -321,6 +337,20 @@ SQLSMALLINT MADB_GetTypeFromConciseType(SQLSMALLINT ConciseType)
   case SQL_C_TIME:
   case SQL_C_TIMESTAMP:
     return SQL_DATETIME;
+  case SQL_C_INTERVAL_YEAR:
+  case SQL_C_INTERVAL_YEAR_TO_MONTH:
+  case SQL_C_INTERVAL_MONTH:
+  case SQL_C_INTERVAL_DAY:
+  case SQL_C_INTERVAL_DAY_TO_HOUR:
+  case SQL_C_INTERVAL_DAY_TO_MINUTE:
+  case SQL_C_INTERVAL_DAY_TO_SECOND:
+  case SQL_C_INTERVAL_HOUR:
+  case SQL_C_INTERVAL_HOUR_TO_MINUTE:
+  case SQL_C_INTERVAL_HOUR_TO_SECOND:
+  case SQL_C_INTERVAL_MINUTE:
+  case SQL_C_INTERVAL_MINUTE_TO_SECOND:
+  case SQL_C_INTERVAL_SECOND:
+      return SQL_INTERVAL;
   default:
     return ConciseType;
   }
